@@ -1,5 +1,5 @@
 '''
-assets
+Assets
 ======
 
 The following methods allow for interaction into the Tenable.io
@@ -9,15 +9,7 @@ Methods available on ``tio.assets``:
 
 .. rst-class:: hide-signature
 .. autoclass:: AssetsAPI
-
-    .. automethod:: asset_import
-    .. automethod:: delete
-    .. automethod:: details
-    .. automethod:: import_job_details
-    .. automethod:: list
-    .. automethod:: list_import_jobs
-    .. automethod:: tags
-    .. automethod:: bulk_delete
+    :members:
 '''
 from tenable.io.base import TIOEndpoint
 
@@ -148,8 +140,8 @@ class AssetsAPI(TIOEndpoint):
         additional properties.
 
         Args:
-            *assets (list):
-                The list of asset dictionaries
+            *assets (dict):
+                One or more asset definition dictionaries
             source (str):
                 An identifier to be used to upload the assets.
 
@@ -158,12 +150,29 @@ class AssetsAPI(TIOEndpoint):
                 The job UUID.
 
         Examples:
+            import single asset:
+
             >>> tio.assets.asset_import('example_source', {
             ...     'fqdn': ['example.py.test'],
             ...     'ipv4': ['192.168.254.1'],
             ...     'netbios_name': 'example',
             ...     'mac_address': ['00:00:00:00:00:00']
             ... })
+
+            import multiple asset:
+
+            >>> tio.assets.asset_import('multiple_asset_example_source',
+            ...     {
+            ...         'fqdn': ['example_one.py.test'],
+            ...         'ipv4': ['192.168.1.1'],
+            ...         'netbios_name': 'example_one',
+            ...         'mac_address': ['00:00:00:00:00:00']
+            ...     },{
+            ...         'fqdn': ['example_two.py.test'],
+            ...         'ipv4': ['192.168.255.1'],
+            ...         'netbios_name': 'example_two',
+            ...         'mac_address': ['00:00:00:00:00:00']
+            ...     })
         '''
         # We will likely want to perform some more stringent checking of the
         # asset resources that are being defined, however a simple type check
@@ -243,7 +252,7 @@ class AssetsAPI(TIOEndpoint):
 
         return self._api.post('api/v2/assets/bulk-jobs/move-to-network', json=payload).json()
 
-    def bulk_delete(self, *filters, filter_type=None):
+    def bulk_delete(self, *filters, hard_delete=None, filter_type=None):
         '''
         Deletes the specified assets.
 
@@ -259,6 +268,8 @@ class AssetsAPI(TIOEndpoint):
                 filters have to match (``AND``) or any of the filters have to
                 match (``OR``).  If not specified, the default behavior is to
                 assume filter_type is ``AND``.
+            hard_delete (bool, optional):
+                Should the assets be completely removed with all related data?
 
         Returns:
             :obj:`dict`:
@@ -277,6 +288,8 @@ class AssetsAPI(TIOEndpoint):
         parsed = self._parse_filters(
             filters, self._api.filters.workbench_asset_filters(), rtype='assets')['asset']
 
+        if hard_delete:
+            payload['hard_delete'] = self._check('hard_delete', hard_delete, bool)
         payload['query'] = {filter_type: parsed}
 
         return self._api.post('api/v2/assets/bulk-jobs/delete', json=payload).json()
