@@ -1,5 +1,5 @@
 '''
-editor
+Editor
 ======
 
 The following methods allow for interaction into the Tenable.io
